@@ -1,5 +1,7 @@
 #include "./testutils.h"
 
+using namespace CppUtilities;
+
 #include "../conversion/stringconversion.h"
 
 /*!
@@ -32,10 +34,15 @@ std::ostream &operator<<(std::ostream &out, const std::wstring &s)
 #include "../io/nativefilestream.h"
 #include "../io/path.h"
 
+#ifdef CPP_UTILITIES_USE_LIBARCHIVE
+#include "../io/archive.h"
+#endif
+
 #include <cppunit/TestFixture.h>
 #include <cppunit/extensions/HelperMacros.h>
 
 #include <algorithm>
+#include <cstddef>
 #include <fstream>
 #include <regex>
 #include <sstream>
@@ -50,7 +57,6 @@ std::ostream &operator<<(std::ostream &out, const std::wstring &s)
 #endif
 
 using namespace std;
-using namespace CppUtilities;
 using namespace CppUtilities::Literals;
 using namespace CPPUNIT_NS;
 
@@ -73,6 +79,9 @@ class IoTests : public TestFixture {
     CPPUNIT_TEST(testAnsiEscapeCodes);
 #ifdef CPP_UTILITIES_USE_NATIVE_FILE_BUFFER
     CPPUNIT_TEST(testNativeFileStream);
+#endif
+#ifdef CPP_UTILITIES_USE_LIBARCHIVE
+    CPPUNIT_TEST(testExtractingArchive);
 #endif
     CPPUNIT_TEST_SUITE_END();
 
@@ -95,6 +104,9 @@ public:
 #ifdef CPP_UTILITIES_USE_NATIVE_FILE_BUFFER
     void testNativeFileStream();
 #endif
+#ifdef CPP_UTILITIES_USE_LIBARCHIVE
+    void testExtractingArchive();
+#endif
 };
 
 CPPUNIT_TEST_SUITE_REGISTRATION(IoTests);
@@ -323,14 +335,14 @@ void IoTests::testBufferSearch()
     bs(buffer, 0);
     CPPUNIT_ASSERT(!hasResult);
     std::strcpy(buffer, "Starting Updated");
-    bs(std::string_view(buffer, 16));
+    CPPUNIT_ASSERT(bs.process(std::string_view(buffer, 16)) == nullptr);
     CPPUNIT_ASSERT(!hasResult);
     std::strcpy(buffer, " version: some ");
     bs(buffer, 15);
     CPPUNIT_ASSERT(!hasResult);
     expectedResult = "some version number";
     std::strcpy(buffer, "version number\tmore chars");
-    bs(buffer, 25);
+    CPPUNIT_ASSERT_EQUAL(static_cast<std::ptrdiff_t>(14), bs.process(buffer, 25) - buffer);
     CPPUNIT_ASSERT(hasResult);
     hasResult = false;
     std::strcpy(buffer, "... Starting build ...");
@@ -568,6 +580,7 @@ void IoTests::testCopyWithNativeFileStream()
     const auto isAborted = [] { return false; };
     const auto callback = [&percentage](double p) { percentage = p; };
     testFile.seekg(0);
+    outputStream.close();
     outputStream.open(outputPath, ios_base::out | ios_base::trunc | ios_base::binary);
     copyHelper.callbackCopy(testFile, outputStream, 50, isAborted, callback);
     CPPUNIT_ASSERT_EQUAL(1.0, percentage);
@@ -649,7 +662,6 @@ void IoTests::testAnsiEscapeCodes()
     ss1 << EscapeCodes::color(EscapeCodes::Color::Blue, EscapeCodes::Color::Red, EscapeCodes::TextAttribute::Blink)
         << "blue, blinking text on red background" << EscapeCodes::TextAttribute::Reset << '\n';
     cout << "\noutput for formatting with ANSI escape codes:\n" << ss1.str() << "---------------------------------------------\n";
-    fstream("/tmp/test.txt", ios_base::out | ios_base::trunc) << ss1.str();
     CPPUNIT_ASSERT_EQUAL("\033[1;31mError: \033[0m\033[1msome error\033[0m\n"
                          "\033[1;33mWarning: \033[0m\033[1msome warning\033[0m\n"
                          "\033[1;34mInfo: \033[0m\033[1msome info\033[0m\n"
@@ -769,3 +781,31 @@ void IoTests::testNativeFileStream()
     CPPUNIT_ASSERT_EQUAL("barfoo"s, readFile(txtFilePath, 7));
 }
 #endif
+
+#ifdef CPP_UTILITIES_USE_LIBARCHIVE
+void IoTests::testExtractingArchive()
+{
+    const auto archivePath = testFilePath("archive-test.zip");
+    const auto archiveContents = extractFiles(archivePath);
+    const auto &root = archiveContents.at(std::string());
+    const auto &subdir = archiveContents.at("subdir");
+    const auto &subsubdir = archiveContents.at("subdir/foo");
+
+    CPPUNIT_ASSERT_EQUAL(1_st, root.size());
+    CPPUNIT_ASSERT_EQUAL("test.txt"s, root.at(0).name);
+    CPPUNIT_ASSERT_EQUAL(ArchiveFileType::Regular, root.at(0).type);
+    CPPUNIT_ASSERT_EQUAL(DateTime::fromDate(1970, 1, 1), root.at(0).creationTime);
+    CPPUNIT_ASSERT_EQUAL(DateTime::fromDateAndTime(2024, 3, 3, 19, 46, 42), root.at(0).modificationTime);
+    CPPUNIT_ASSERT_EQUAL("testfile\n"s, root.at(0).content);
+
+    CPPUNIT_ASSERT_EQUAL(1_st, subdir.size());
+    CPPUNIT_ASSERT_EQUAL("nested-testfile.txt"s, subdir.at(0).name);
+    CPPUNIT_ASSERT_EQUAL(ArchiveFileType::Regular, subdir.at(0).type);
+    CPPUNIT_ASSERT_EQUAL("some file\n"s, subdir.at(0).content);
+
+    CPPUNIT_ASSERT_EQUAL(1_st, subsubdir.size());
+    CPPUNIT_ASSERT_EQUAL("bar"s, subsubdir.at(0).name);
+    CPPUNIT_ASSERT_EQUAL(ArchiveFileType::Regular, subsubdir.at(0).type);
+    CPPUNIT_ASSERT_EQUAL(std::string(), subsubdir.at(0).content);
+}
+#endif
